@@ -2,7 +2,7 @@
 
 __author__ = '@snovvcrash'
 __site__ = 'https://github.com/snovvcrash/DivideAndScan'
-__version__ = '0.2.6'
+__version__ = '0.3.0'
 
 import time
 from datetime import datetime, timedelta
@@ -21,6 +21,8 @@ BANNER = """\
 
 SEP = '#############################################'
 
+XML_REPORTS = []
+
 
 class Logger:
 	"""Event logger class (measures runtime, print messages)."""
@@ -62,6 +64,16 @@ class Logger:
 		"""
 		print(f'[\033[1;32m+\033[0m] {msg}')
 
+	@staticmethod
+	def print_warning(msg):
+		"""
+		Print warning message.
+
+		:param msg: the message to print
+		:type msg: str
+		"""
+		print(f'[\033[1;33m!\033[0m] {msg}')
+
 	@staticmethod
 	def print_error(msg):
 		"""
